@@ -10,7 +10,7 @@ fn main() {
     let args: Vec<String> = env::args().skip(1).collect();
     for path in &args {
         match Song::new(&path) {
-            Ok(song) => println!("{}: {:?}", path, song.analysis,),
+            Ok(song) => println!("{}: {:?}", path, song.analysis),
             Err(e) => println!("{}: {}", path, e),
         }
     }
